@@ -2,10 +2,16 @@ package action
 
 import (
 	"context"
+	"fmt"
+	"net/url"
+	"os"
+	"path/filepath"
 	"sort"
 	"strings"
 
+	"github.com/hashicorp/go-getter"
 	"github.com/helmwave/helmwave/pkg/cache"
+	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/plan"
 	log "github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
@@ -15,19 +21,65 @@ var _ Action = (*Build)(nil)
 
 // Build is a struct for running 'build' CLI command.
 type Build struct {
-	yml            *Yml
-	diff           *Diff
-	options        plan.BuildOptions
-	plandir        string
-	diffMode       string
-	chartsCacheDir string
-	tags           cli.StringSlice
-	autoYml        bool
-	skipUnchanged  bool
+	yml           *Yml
+	diff          *Diff
+	options       plan.BuildOptions
+	remoteSource  string
+	plandir       string
+	diffMode      string
+	tags          cli.StringSlice
+	autoYml       bool
+	skipUnchanged bool
 }
 
 // Run is the main function for 'build' CLI command.
+//
+//nolint:funlen,gocognit,cyclop
 func (i *Build) Run(ctx context.Context) (err error) {
+	wd, err := os.Getwd()
+	if err != nil {
+		return fmt.Errorf("failed to get current directory: %w", err)
+	}
+
+	if i.remoteSource != "" {
+		remoteSource, err := url.Parse(i.remoteSource)
+		if err != nil {
+			return fmt.Errorf("failed to parse remote source: %w", err)
+		}
+
+		downloadPath := cache.DefaultConfig.GetRemoteSourcePath(remoteSource)
+		err = getter.Get(
+			downloadPath,
+			i.remoteSource,
+			getter.WithContext(ctx),
+			getter.WithDetectors(getter.Detectors),
+			getter.WithGetters(getter.Getters),
+			getter.WithDecompressors(getter.Decompressors),
+		)
+		if err != nil {
+			return fmt.Errorf("failed to download remote source: %w", err)
+		}
+
+		// we need to move plandir back to where it should be
+		defer func() {
+			srcPlandir := filepath.Join(downloadPath, i.plandir)
+			destPlandir := filepath.Join(wd, i.plandir)
+			err := os.RemoveAll(destPlandir)
+			if err != nil {
+				log.WithError(err).Error("failed to clean plandir")
+			}
+			err = helper.MoveFile(srcPlandir, destPlandir)
+			if err != nil {
+				log.WithError(err).Error("failed to move plandir")
+			}
+		}()
+
+		err = os.Chdir(downloadPath)
+		if err != nil {
+			return fmt.Errorf("failed to chdir to downloaded remote source: %w", err)
+		}
+	}
+
 	if i.autoYml {
 		err = i.yml.Run(ctx)
 		if err != nil {
@@ -35,11 +87,6 @@ func (i *Build) Run(ctx context.Context) (err error) {
 		}
 	}
 
-	err = cache.ChartsCache.Init(i.chartsCacheDir)
-	if err != nil {
-		return err
-	}
-
 	newPlan := plan.New(i.plandir)
 
 	i.options.Tags = i.normalizeTags()
@@ -63,12 +110,12 @@ func (i *Build) Run(ctx context.Context) (err error) {
 				return err
 			}
 
-			newPlan.DiffPlan(oldPlan, i.diff.ShowSecret, i.diff.Wide)
+			newPlan.DiffPlan(oldPlan, i.diff.Options)
 		}
 
 	case DiffModeLive:
 		log.Info("🆚 Diff manifests in the kubernetes cluster")
-		newPlan.DiffLive(ctx, i.diff.ShowSecret, i.diff.Wide, i.diff.ThreeWayMerge)
+		newPlan.DiffLive(ctx, i.diff.Options, i.diff.ThreeWayMerge)
 	case DiffModeNone:
 		log.Info("🆚 Skip diffing")
 	default:
@@ -88,9 +135,15 @@ func (i *Build) Run(ctx context.Context) (err error) {
 // Cmd returns 'build' *cli.Command.
 func (i *Build) Cmd() *cli.Command {
 	return &cli.Command{
-		Name:   "build",
-		Usage:  "🏗 build a plan",
-		Flags:  i.flags(),
+		Name:     "build",
+		Category: Step1,
+		Usage:    "🏗 build a plan",
+		Flags:    i.flags(),
+		Before: func(q *cli.Context) error {
+			i.diff.FixFields()
+
+			return nil
+		},
 		Action: toCtx(i.Run),
 	}
 }
@@ -108,15 +161,23 @@ func (i *Build) flags() []cli.Flag {
 		flagGraphWidth(&i.options.GraphWidth),
 		flagSkipUnchanged(&i.skipUnchanged),
 		flagDiffMode(&i.diffMode),
-		flagChartsCacheDir(&i.chartsCacheDir),
 
 		&cli.BoolFlag{
 			Name:        "yml",
 			Usage:       "auto helmwave.yml.tpl --> helmwave.yml",
 			Value:       false,
+			Category:    "YML",
 			EnvVars:     []string{"HELMWAVE_AUTO_YML", "HELMWAVE_AUTO_YAML"},
 			Destination: &i.autoYml,
 		},
+		&cli.StringFlag{
+			Name:        "remote-source",
+			Usage:       "go-getter URL to download build sources",
+			Value:       "",
+			Category:    "BUILD",
+			EnvVars:     []string{"HELMWAVE_REMOTE_SOURCE"},
+			Destination: &i.remoteSource,
+		},
 	}
 
 	self = append(self, i.diff.flags()...)
@@ -133,10 +194,7 @@ func (i *Build) normalizeTags() []string {
 // normalizeTags normalizes and splits comma-separated tag list.
 // ["c", " b ", "a "] -> ["a", "b", "c"].
 func normalizeTagList(tags []string) []string {
-	m := make([]string, len(tags))
-	for i, t := range tags {
-		m[i] = strings.TrimSpace(t)
-	}
+	m := helper.SlicesMap(tags, strings.TrimSpace)
 	sort.Strings(m)
 
 	return m
