@@ -8,6 +8,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/databus23/helm-diff/v3/diff"
 	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	"github.com/stretchr/testify/suite"
@@ -16,6 +17,8 @@ import (
 
 type DiffLiveTestSuite struct {
 	suite.Suite
+
+	ctx context.Context
 }
 
 //nolint:paralleltest // uses helm repository.yaml flock
@@ -24,8 +27,12 @@ func TestDiffLiveTestSuite(t *testing.T) {
 	suite.Run(t, new(DiffLiveTestSuite))
 }
 
+func (ts *DiffLiveTestSuite) SetupTest() {
+	ts.ctx = tests.GetContext(ts.T())
+}
+
 func (ts *DiffLiveTestSuite) TestCmd() {
-	s := &DiffLive{}
+	s := &DiffLive{diff: &Diff{Options: &diff.Options{}}}
 	cmd := s.Cmd()
 
 	ts.Require().NotNil(cmd)
@@ -44,13 +51,13 @@ func (ts *DiffLiveTestSuite) TestRun() {
 		plandir:  tmpDir,
 		tags:     cli.StringSlice{},
 		yml:      y,
-		diff:     &Diff{},
+		diff:     &Diff{Options: &diff.Options{}},
 		diffMode: DiffModeLive,
 	}
 
 	d := DiffLive{diff: s.diff, plandir: s.plandir}
 
-	ts.Require().ErrorIs(d.Run(context.Background()), os.ErrNotExist)
-	ts.Require().NoError(s.Run(context.Background()))
-	ts.Require().NoError(d.Run(context.Background()))
+	ts.Require().ErrorIs(d.Run(ts.ctx), os.ErrNotExist)
+	ts.Require().NoError(s.Run(ts.ctx))
+	ts.Require().NoError(d.Run(ts.ctx))
 }
