@@ -26,6 +26,7 @@ func (l *Settings) Flags() []cli.Flag {
 			Name:        "log-format",
 			Usage:       "You can set: [ text | json | pad | emoji ]",
 			Value:       "emoji",
+			Category:    "LOGGER",
 			EnvVars:     []string{"HELMWAVE_LOG_FORMAT"},
 			Destination: &l.format,
 		},
@@ -33,6 +34,7 @@ func (l *Settings) Flags() []cli.Flag {
 			Name:        "log-level",
 			Usage:       "You can set: [ debug | info | warn  | fatal | panic | trace ]",
 			Value:       "info",
+			Category:    "LOGGER",
 			EnvVars:     []string{"HELMWAVE_LOG_LEVEL", "HELMWAVE_LOG_LVL"},
 			Destination: &l.level,
 		},
@@ -40,6 +42,7 @@ func (l *Settings) Flags() []cli.Flag {
 			Name:        "log-color",
 			Usage:       "on/off color",
 			Value:       true,
+			Category:    "LOGGER",
 			EnvVars:     []string{"HELMWAVE_LOG_COLOR"},
 			Destination: &l.color,
 		},
@@ -47,6 +50,7 @@ func (l *Settings) Flags() []cli.Flag {
 			Name:        "log-timestamps",
 			Usage:       "Add timestamps to log messages",
 			Value:       false,
+			Category:    "LOGGER",
 			EnvVars:     []string{"HELMWAVE_LOG_TIMESTAMPS"},
 			Destination: &l.timestamps,
 		},
@@ -54,7 +58,7 @@ func (l *Settings) Flags() []cli.Flag {
 }
 
 // Run initializes logger.
-func (l *Settings) Run(c *cli.Context) error {
+func (l *Settings) Run(_ *cli.Context) error {
 	return l.Init()
 }
 
