@@ -3,6 +3,7 @@ package release
 import (
 	"context"
 	"fmt"
+	"slices"
 
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/log"
@@ -17,27 +18,21 @@ import (
 
 // Config is an interface to manage particular helm release.
 type Config interface {
-	helper.EqualChecker[Config]
 	log.LoggerGetter
+	HelmActionRunner
+
 	Uniq() uniqname.UniqName
-	Sync(context.Context) (*release.Release, error)
-	SyncDryRun(context.Context) (*release.Release, error)
 	AllowFailure() bool
-	DryRun(bool)
+	DryRun(dryRun bool)
 	ChartDepsUpd() error
-	DownloadChart(string) error
-	BuildValues(string, string) error
-	Uninstall(context.Context) (*release.UninstallReleaseResponse, error)
-	Get(int) (*release.Release, error)
-	List() (*release.Release, error)
-	Rollback(context.Context, int) error
-	Status() (*release.Release, error)
+	DownloadChart(tmpDir string) error
+	BuildValues(ctx context.Context, dir, templater string) error
 	Name() string
 	Namespace() string
 	Chart() *Chart
 	SetChartName(string)
 	DependsOn() []*DependsOnReference
-	SetDependsOn([]*DependsOnReference)
+	SetDependsOn(deps []*DependsOnReference)
 	Tags() []string
 	Repo() string
 	Values() []ValuesReference
@@ -48,7 +43,17 @@ type Config interface {
 	OfflineKubeVersion() *chartutil.KubeVersion
 	Validate() error
 	Monitors() []MonitorReference
-	NotifyMonitorsFailed(context.Context, ...monitor.Config)
+	NotifyMonitorsFailed(ctx context.Context, monitors ...monitor.Config)
+}
+
+type HelmActionRunner interface {
+	SyncDryRun(ctx context.Context, runHooks bool) (*release.Release, error)
+	Sync(ctx context.Context, runHooks bool) (*release.Release, error)
+	Uninstall(ctx context.Context) (*release.UninstallReleaseResponse, error)
+	Get(version int) (*release.Release, error)
+	List() (*release.Release, error)
+	Rollback(ctx context.Context, version int) error
+	Status() (*release.Release, error)
 }
 
 // Configs type of array Config.
@@ -61,11 +66,11 @@ func (r *Configs) UnmarshalYAML(node *yaml.Node) error {
 		return fmt.Errorf("failed to decode release config from YAML: %w", err)
 	}
 
-	*r = make([]Config, len(rr))
-	for i := range rr {
-		rr[i].buildAfterUnmarshal(rr)
-		(*r)[i] = rr[i]
-	}
+	*r = helper.SlicesMap(rr, func(r *config) Config {
+		r.buildAfterUnmarshal(rr)
+
+		return r
+	})
 
 	return nil
 }
@@ -85,11 +90,13 @@ func (r Configs) Contains(rel Config) (Config, bool) {
 }
 
 func (r Configs) ContainsUniq(uniq uniqname.UniqName) (Config, bool) {
-	for _, rel := range r {
-		if rel.Uniq().Equal(uniq) {
-			return rel, true
-		}
+	i := slices.IndexFunc(r, func(rel Config) bool {
+		return rel.Uniq().Equal(uniq)
+	})
+
+	if i == -1 {
+		return nil, false
 	}
 
-	return nil, false
+	return r[i], true
 }
