@@ -15,12 +15,3 @@ func NewValidationError(uniq string) error {
 func (err ValidationError) Error() string {
 	return fmt.Sprintf("failed to validate uniqname: %s", err.Uniq)
 }
-
-func (ValidationError) Is(target error) bool {
-	switch target.(type) {
-	case ValidationError, *ValidationError:
-		return true
-	default:
-		return false
-	}
-}
