@@ -18,7 +18,7 @@ func (s *ValidateTestSuite) TestGood() {
 	}
 
 	for _, d := range data {
-		s.Require().NoError(uniqname.UniqName(d).Validate())
+		s.NoError(uniqname.UniqName(d).Validate())
 	}
 }
 
@@ -36,7 +36,10 @@ func (s *ValidateTestSuite) TestBad() {
 	}
 
 	for _, d := range data {
-		s.Require().ErrorIs(uniqname.UniqName(d).Validate(), uniqname.ValidationError{})
+		u := uniqname.UniqName(d)
+		var e *uniqname.ValidationError
+		s.ErrorAs(u.Validate(), &e)
+		s.Equal(d, e.Uniq)
 	}
 }
 
