@@ -1,14 +1,20 @@
 package release
 
 import (
+	"context"
 	"crypto"
 	_ "crypto/md5" // for crypto.MD5.New to work
 	"encoding/hex"
 	"errors"
 	"fmt"
 	"path/filepath"
+	"slices"
+	"strings"
+	"sync"
+	"time"
 
 	"github.com/helmwave/helmwave/pkg/helper"
+	"github.com/helmwave/helmwave/pkg/parallel"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/invopop/jsonschema"
@@ -88,8 +94,8 @@ func (v *ValuesReference) isURL() bool {
 }
 
 // Download downloads values by source URL and places to destination path.
-func (v *ValuesReference) Download() error {
-	if err := helper.Download(v.Dst, v.Src); err != nil {
+func (v *ValuesReference) Download(ctx context.Context) error {
+	if err := helper.Download(ctx, v.Dst, v.Src); err != nil {
 		return fmt.Errorf("failed to download values %s -> %s: %w", v.Src, v.Dst, err)
 	}
 
@@ -127,14 +133,14 @@ func ProhibitDst(values []ValuesReference) error {
 	return nil
 }
 
-// func (v *ValuesReference) Set(Dst string) *ValuesReference {
-//	v.Dst = Dst
-//	return v
-// }
-
 // SetViaRelease downloads and templates values file.
 // Returns ErrValuesNotExist if values can't be downloaded or doesn't exist in local FS.
-func (v *ValuesReference) SetViaRelease(rel Config, dir, templater string) error {
+func (v *ValuesReference) SetViaRelease(
+	ctx context.Context,
+	rel Config,
+	dir, templater string,
+	renderedFiles *renderedValuesFiles,
+) error {
 	if v.Renderer == "" {
 		v.Renderer = templater
 	}
@@ -151,16 +157,38 @@ func (v *ValuesReference) SetViaRelease(rel Config, dir, templater string) error
 		Release: rel,
 	}
 
-	err := v.fetch(l)
+	err := v.fetch(ctx, l)
 	if err != nil {
 		return err
 	}
 
-	delimOption := template.SetDelimiters(v.DelimiterLeft, v.DelimiterRight)
+	opts := []template.TemplaterOptions{
+		template.SetDelimiters(v.DelimiterLeft, v.DelimiterRight),
+	}
+
+	if renderedFiles != nil {
+		buf := &strings.Builder{}
+		defer func() {
+			renderedFiles.Add(v.Src, buf)
+		}()
+
+		opts = append(opts,
+			template.CopyOutput(buf),
+			template.AddFunc("getValues", func(filename string) (any, error) {
+				s := renderedFiles.Get(filename).String()
+
+				var res any
+				err := yaml.Unmarshal([]byte(s), &res)
+
+				//nolint:wrapcheck
+				return res, err
+			},
+			))
+	}
 	if v.isURL() {
-		err = template.Tpl2yml(v.Dst, v.Dst, data, v.Renderer, delimOption)
+		err = template.Tpl2yml(ctx, v.Dst, v.Dst, data, v.Renderer, opts...)
 	} else {
-		err = template.Tpl2yml(v.Src, v.Dst, data, v.Renderer, delimOption)
+		err = template.Tpl2yml(ctx, v.Src, v.Dst, data, v.Renderer, opts...)
 	}
 
 	if err != nil {
@@ -170,9 +198,9 @@ func (v *ValuesReference) SetViaRelease(rel Config, dir, templater string) error
 	return nil
 }
 
-func (v *ValuesReference) fetch(l *log.Entry) error {
+func (v *ValuesReference) fetch(ctx context.Context, l *log.Entry) error {
 	if v.isURL() {
-		err := v.Download()
+		err := v.Download(ctx)
 		if err != nil {
 			l.WithError(err).Warnf("%q skipping: cant download", v.Src)
 
@@ -187,23 +215,84 @@ func (v *ValuesReference) fetch(l *log.Entry) error {
 	return nil
 }
 
-func (rel *config) BuildValues(dir, templater string) error {
+func (rel *config) BuildValues(ctx context.Context, dir, templater string) error {
 	vals := rel.Values()
-	for i := len(vals) - 1; i >= 0; i-- {
-		v := vals[i]
-		err := v.SetViaRelease(rel, dir, templater)
-		switch {
-		case !v.Strict && errors.Is(ErrValuesNotExist, err):
-			rel.Logger().WithError(err).WithField("values", v).Warn("skipping values...")
-			rel.ValuesF = append(rel.ValuesF[:i], rel.ValuesF[i+1:]...)
-		case err != nil:
-			rel.Logger().WithError(err).WithField("values", v).Error("failed to build values")
 
-			return err
-		default:
-			rel.Values()[i] = v
+	wg := parallel.NewWaitGroup()
+	wg.Add(len(vals))
+
+	// we need to keep rendered values in memory to use them in other values
+	renderedValuesMap := newRenderedValuesFiles()
+	// we need to keep track of values that we need to delete (e.g. non-existent files)
+	toDeleteMap := make(map[*ValuesReference]bool)
+
+	// just in case of dependency cycle or long http requests
+	ctx, cancel := context.WithTimeout(ctx, time.Minute)
+	defer cancel()
+
+	l := rel.Logger()
+
+	for i := range vals {
+		go func(v *ValuesReference) {
+			defer wg.Done()
+
+			l := l.WithField("values", v)
+
+			err := v.SetViaRelease(ctx, rel, dir, templater, renderedValuesMap)
+			switch {
+			case !v.Strict && errors.Is(ErrValuesNotExist, err):
+				l.WithError(err).Warn("skipping values...")
+				toDeleteMap[v] = true
+			case err != nil:
+				l.WithError(err).Error("failed to build values")
+
+				wg.ErrChan() <- err
+			}
+		}(&vals[i])
+	}
+
+	err := wg.WaitWithContext(ctx)
+	if err != nil {
+		return err
+	}
+
+	for i := len(vals) - 1; i >= 0; i-- {
+		if toDeleteMap[&vals[i]] {
+			vals = slices.Delete(vals, i, i+1)
 		}
 	}
+	rel.ValuesF = vals
 
 	return nil
 }
+
+type renderedValuesFiles struct {
+	bufs map[string]fmt.Stringer
+	cond *sync.Cond
+}
+
+func newRenderedValuesFiles() *renderedValuesFiles {
+	r := &renderedValuesFiles{
+		bufs: make(map[string]fmt.Stringer),
+	}
+	r.cond = sync.NewCond(&sync.Mutex{})
+
+	return r
+}
+
+func (r *renderedValuesFiles) Add(name string, buf fmt.Stringer) {
+	r.cond.L.Lock()
+	r.bufs[name] = buf
+	r.cond.Broadcast()
+	r.cond.L.Unlock()
+}
+
+func (r *renderedValuesFiles) Get(name string) fmt.Stringer {
+	r.cond.L.Lock()
+	for r.bufs[name] == nil {
+		r.cond.Wait()
+	}
+	r.cond.L.Unlock()
+
+	return r.bufs[name]
+}
